@@ -11,8 +11,9 @@ File::Replace::Fancy - Perl extension that extends the File::Replace module
 
 =head1 Description
 
-**This is a stub module.** You don't need to C<use> it.
-Please see L<File::Replace> for the features provided by this distribution.
+B<This is a stub module.> You don't need to C<use> it.
+Please see the functions C<replace> and C<replace2> in
+L<File::Replace> for the features provided by this distribution.
 
 =head1 Author, Copyright, and License
 
